@@ -43,7 +43,7 @@ class Normalizer:
         self.blacklist = pd.read_csv(pathes.get("blacklist", "receipt_parser/data/blacklist.csv"))[
             "name"
         ].values
-        self.brands = pd.read_csv(pathes.get("brands", "receipt_parser/data/cleaned/brands_en.csv"))[
+        self.brands = pd.read_csv(pathes.get("brands_en", "receipt_parser/data/cleaned/brands_en.csv"))[
             "brand"
         ].values
 
