@@ -2,6 +2,8 @@
 Provide various types of technologies for recognition
 and normalization product descriptions.
 """
+import os
+import wget
 from typing import Union, Optional, Dict
 import pandas as pd  # type: ignore
 try:
@@ -13,9 +15,50 @@ except ImportError:
 except ModuleNotFoundError:
     from .finder import Finder
     from .normalizer import Normalizer
+
+
+class DownloadData:
+
+    def __init__(self):
+        print("It's need to download some data...")
+        self.files = {
+            "cleaned/all_clean.csv": "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/cleaned/all_clean.csv",
+            "cleaned/brands_en.csv": "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/cleaned/brands_en.csv",
+            "cleaned/brands_ru.csv": "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/cleaned/brands_ru.csv",
+            "cleaned/products.csv": "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/cleaned/products.csv",
+            "blacklist.csv": "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/blacklist.csv"
+        }
+        self.home_folder = os.path.join(os.getcwd(), 'data')
+
+    @staticmethod
+    def _is_folder_exist() -> bool:
+        pwd: str = os.getcwd()
+        data_folder: str = os.path.join(pwd, 'data')
+        return os.path.isdir(data_folder)
+
+    @staticmethod
+    def _make_dirs() -> None:
+        os.makedirs('data')
+        os.makedirs(os.path.join('data', 'cleaned'))
     
-import os
-import wget
+    def download_files(self) -> None:
+        for name, url in self.files.items():
+            print(f"Download {name.split('/')[-1]}")
+            wget.download(url, os.path.join("data", name))
+
+    def get_pathes(self) -> Dict[str, str]:
+        pathes: Dict[str, str] = {}
+
+        for path in self.files.keys():
+            name = path.split("/")[-1].split(".")[0]
+            pathes[name] = os.path.join(self.home_folder, path)
+        return pathes
+    
+    def download(self):
+        if not self._is_folder_exist():
+            self._make_dirs()
+            self.download_files()
+        return self.get_pathes()
 
 
 # pylint: disable=too-few-public-methods
@@ -47,15 +90,8 @@ class RuleBased:
     """
 
     def __init__(self, pathes: Optional[Dict[str, str]] = None):
-        print('TEST')
-        print('LS\n', os.listdir())
-        
-        print('\n\nWGET')
-        url = "https://raw.githubusercontent.com/slgero/receipt_parser/master/receipt_parser/data/blacklist.csv"
-        wget.download(url, 'lol.csv')
-        print('\n\nWGET DONE')
-        
-        pathes = pathes or {}
+        download_pathes = DownloadData().download()
+        pathes = pathes or download_pathes
 
         self.norm = Normalizer(pathes)
         self.find = Finder(pathes)
